@@ -22,8 +22,10 @@ copyright = "2022, Stephen Dunn"
 author = "Stephen Dunn"
 
 # The full version, including alpha/beta/rc tags
-with open("../../VERSION", "rt") as fp:
-    release = fp.readline()
+with open("../../src/slidingpuzzle/__about__.py", "rt") as fp:
+    about = fp.readlines()
+
+version = next(l for l in about if "version" in l).split("\"")[1]
 
 # -- General configuration ---------------------------------------------------
 
